@@ -1,5 +1,6 @@
 import json
 import os
+import sys
 from difflib import get_close_matches
 from pick import pick
 from functools import lru_cache
@@ -96,7 +97,8 @@ def set_location(location_in):
 
     try:
         if not possible_places:
-            raise ValueError(f'{translations.unknown_location[lang]}')
+            print(f'{translations.unknown_location[lang]}')
+            sys.exit()
         else:
             # Shows options
             option, chosen = pick(places_names, 'Choose a location: ')
